﻿using System;
using System.Collections.Generic;
using System.Linq;
using MyMVC;
using MongoDB;


// 说明：MyMVC是一个WEB框架，博客地址：http://www.cnblogs.com/fish-li/archive/2012/02/12/2348395.html


// 说明：因为MonogDB并不支持【自增数据类型】，所以，我把所有实体的ID字段的类型全改为字符串，它们将保存GUID字符串。

// 与原版示例不同，这里直接在订单明细中保存了ProductName，Unit 。主要是为了减少与数据库的交互次数（事实上这样做也合理）。


namespace MyLab.AjaxService
{

	public static class AjaxData
	{
		[Action]
		public static string ImportData()
		{
			if( System.Web.HttpContext.Current.Request.IsLocal == false ) {
				System.Threading.Thread.Sleep(2000);
				return "你不能执行这个操作。";
			}

			try {
				using( MyMongoDb mm = new MyMongoDb() ) {

					// 先从SqlServer中获取所有数据。
					using( ClownFish.DbContext sqlserver = new ClownFish.DbContext(false) ) {
						sqlserver.CreateCommand("select * from Categories", System.Data.CommandType.Text);
						List<Category> categoryList = sqlserver.FillList<Category>();

						sqlserver.CreateCommand("select * from Customers", System.Data.CommandType.Text);
						List<Customer> customerList = sqlserver.FillList<Customer>();

						sqlserver.CreateCommand("select * from Products", System.Data.CommandType.Text);
						Dictionary<string, Product> productList =
										sqlserver.FillList<Product>().ToDictionary(x => x.ProductID);

						sqlserver.CreateCommand("select * from Orders", System.Data.CommandType.Text);
						List<OrderItem> ordeList = sqlserver.FillList<OrderItem>();

						sqlserver.CreateCommand("select * from [Order Details]", System.Data.CommandType.Text);
						List<OrderDetail> detailList = sqlserver.FillList<OrderDetail>();

						// 先关闭SqlServer连接。


						// 补入一些原SqlServer表中没有字段信息
						Product product =null;
						foreach( OrderDetail dt in detailList ) {
							//dt.OrderDetailID = Guid.NewGuid().ToString("N");

							product = productList[dt.ProductID];
							dt.ProductName = product.ProductName;
							dt.Unit = product.Unit;
						}


						var db = mm.CurrentDb;


						// 然后，清空MongoDB中所有数据。
						var categories = db.GetCollection<Category>();
						categories.Remove(x => true);

						var customers = db.GetCollection<Customer>();
						customers.Remove(x => true);

						var products = db.GetCollection<Product>();
						products.Remove(x => true);

						var orders = mm.GetCollection<OrderItem>(OrderBLL.STR_Orders);
						orders.Remove(x => true);


						// 导入数据
						categoryList.ForEach(x => categories.Insert(x));
						customerList.ForEach(x => customers.Insert(x));
						foreach( var p in productList )
							products.Insert(p.Value);


						// MongoDB不支持事务，为了能保证订单明细与主记录一起被【同步】保存，所以明细记录不单独保存。
						foreach( OrderItem ord in ordeList ) {
							ord.Detail = detailList.Where(x => x.OrderID == ord.OrderID).ToList();
							orders.Insert(ord);
						}
					}
				}
			}
			catch( Exception ex ) {
				return ex.Message;
			}

			return "操作成功。";
		}

	}
}
