﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using MyMVC;
using ClownFish;

// 说明：MyMVC是一个WEB框架，博客地址：http://www.cnblogs.com/fish-li/archive/2012/02/12/2348395.html
// 说明：ClownFish是一个数据访问层，博客地址：http://www.cnblogs.com/fish-li/archive/2012/07/17/ClownFish.html


namespace MyLab.AjaxService
{

	/// <summary>
	/// Ajax服务类，提供“订单记录”相关操作
	/// </summary>
	public class AjaxOrder
	{
		//--------------------------------------------------------------
		// 注意： 
		//     用于Ajax的类及方法，可以是静态的，也可以是非静态的。
		//--------------------------------------------------------------

		private OrderBLL OrderBLLInstance
		{
			get { return new OrderBLL(); }
		}

		/// <summary>
		/// 新增订单
		/// </summary>
		/// <param name="form"></param>
		/// <returns></returns>
		[Action]
		public string AddOrder(OrderSubmitForm form)
		{
			OrderItem order = form.ConvertToOrderItem();
			return OrderBLLInstance.AddOrder(order);
		}

		/// <summary>
		/// 搜索订单
		/// </summary>
		/// <returns></returns>
		[Action]
		public object Search(OrderSearchOption option)
		{
			option.CheckPagingInfoState();

			List<OrderItem> list = OrderBLLInstance.Search(option);

			return new GridResult<OrderItem>(list, option.TotalRecords);
		}



		/// <summary>
		/// 修改订单状态
		/// </summary>
		/// <param name="orderId"></param>
		/// <param name="finished"></param>
		/// <returns></returns>
		[Action]
		public void SetOrderStatus(string id, bool finished)
		{
			if( string.IsNullOrEmpty(id) )
				throw new MyMessageException("没有指定OrderId");

			OrderBLLInstance.SetOrderStatus(id, finished);
		}

		[Action]
		public string GetById(string id)
		{
			if( string.IsNullOrEmpty(id) )
				throw new MyMessageException("没有指定OrderId");

			OrderItem item = OrderBLLInstance.GetOrderById(id);
			if( item == null )
				throw new MyMessageException("指定的ID值无效。不能找到对应的记录。");

			return item.ToJson();
		}


	}


}


public sealed class OrderSearchOption : PagingInfo
{
	public DateTime StartDate;
	public DateTime EndDate;
}