﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using ClownFish;
using MyMVC;

// 说明：MyMVC是一个WEB框架，博客地址：http://www.cnblogs.com/fish-li/archive/2012/02/12/2348395.html
// 说明：ClownFish是一个数据访问层，博客地址：http://www.cnblogs.com/fish-li/archive/2012/07/17/ClownFish.html

public class ProductPagingInfo : PagingInfo
{
	public string SearchWord = string.Empty;
	public string CategoryId;
}


namespace MyLab.AjaxService
{

	/// <summary>
	/// Ajax服务类，提供“商品记录”相关操作
	/// </summary>
	public class AjaxProduct
	{
		private ProductBLL ProductBLLInstance
		{
			get { return new ProductBLL(); }
		}

		[Action]
		public object List(ProductPagingInfo pagingInfo)
		{
			pagingInfo.CheckPagingInfoState();

			List<Product> List = ProductBLLInstance.SearchProduct(pagingInfo.CategoryId, pagingInfo.SearchWord, pagingInfo);
			return new GridResult<Product>(List, pagingInfo.TotalRecords);
		}

		[Action]
		public void Insert(Product product)
		{
			product.EnsureItemIsOK();

			ProductBLLInstance.Insert(product);
		}

		[Action]
		public void Delete(string id)
		{
			ProductBLLInstance.Delete(id);
		}

		[Action]
		public void Update(Product product)
		{
			product.EnsureItemIsOK();

			ProductBLLInstance.Update(product);
		}

		[Action]
		public void ChangeProductQuantity(string productId, int quantity)
		{
			if( string.IsNullOrEmpty(productId) )
				throw new MyMessageException("没有指定ProductID");

			ProductBLLInstance.ChangeProductQuantity(productId, quantity);
		}

		/// <summary>
		/// 获取指定的商品记录，以JSON格式返回
		/// </summary>
		/// <param name="productId"></param>
		/// <returns></returns>
		[Action]
		public string GetById(string id)
		{
			Product product = ProductBLLInstance.GetProductById(id);
			if( product == null )
				throw new MyMessageException("指定的ID值无效。不能找到对应的记录。");

			return product.ToJson();
		}



		private static readonly string[] UnitArray = new string[] { "个", "件", "只", "双" };

		[Action]
		public string GetUnitList(string unit)
		{
			string result = null;

			if( string.IsNullOrEmpty(unit) ) {
				result = UnitArray.Select((x, index) => new { text = x, selected = index == 0 }).ToList().ToJson();
			}
			else {
				int p = Array.IndexOf(UnitArray, unit);
				if( p >= 0 ) {
					result = UnitArray.Select((x, index) => new { text = x, selected = index == p }).ToList().ToJson();
				}
				else {
					List<string> list = UnitArray.ToList();
					list.Add(unit);
					result = list.Select((x, index) => new { text = x, selected = index == 0 }).ToList().ToJson();
				}
			}
			// 减少一点网络流量，不执行这个操作也没有问题。
			return result.Replace(",\"selected\":false", "");
		}



	}
}
