﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Script.Serialization;
using System.Text;
using MongoDB;
using ClownFish;

/// <summary>
/// 一些扩展方法
/// </summary>
public static class Extension
{

	/// <summary>
	/// 返回对象的JSON序列化的字符串
	/// </summary>
	/// <param name="obj"></param>
	/// <returns></returns>
	public static string ToJson(this object obj)
	{
		if( obj == null )
			return string.Empty;

		return (new JavaScriptSerializer()).Serialize(obj);
	}

	public static void CheckPagingInfoState(this PagingInfo pagingInfo)
	{
		if( pagingInfo.PageIndex > 0 )
			pagingInfo.PageIndex--;

		if( pagingInfo.PageSize < 1 )
			pagingInfo.PageSize = AppHelper.DefaultPageSize;
	}

	public static string ToText(this int num)
	{
		if( num == 0 )
			return string.Empty;
		else
			return num.ToString();
	}

	public static string ToText(this decimal num)
	{
		if( num == 0M )
			return string.Empty;
		else
			return num.ToString("F2");
	}

	public static DateTime PadTime(this DateTime date)
	{
		DateTime now = DateTime.Now;
		return new DateTime(date.Year, date.Month, date.Day, now.Hour, now.Minute, now.Second);
	}


	public static List<KeyValuePair<string, string>> SplitString(this string line, char separator1, char separator2)
	{
		if( string.IsNullOrEmpty(line) )
			return new List<KeyValuePair<string, string>>();

		string[] itemArray = line.Split(new char[] { separator1 }, StringSplitOptions.RemoveEmptyEntries);
		List<KeyValuePair<string, string>> list = new List<KeyValuePair<string, string>>(itemArray.Length);

		char[] separator2Array = new char[] { separator2 };

		foreach( string item in itemArray ) {
			string[] parts = item.Split(separator2Array, StringSplitOptions.RemoveEmptyEntries);
			if( parts.Length != 2 )
				throw new ArgumentException("要拆分的字符串的格式无效。");

			list.Add(new KeyValuePair<string, string>(parts[0], parts[1]));
		}
		return list;
	}

}
